summaryrefslogtreecommitdiffstats
path: root/src/usr/htmgt/htmgt_utility.H
diff options
context:
space:
mode:
authorChris Cain <cjcain@us.ibm.com>2017-06-05 11:48:32 -0500
committerDaniel M. Crowell <dcrowell@us.ibm.com>2017-06-22 09:30:04 -0400
commit7d4cab0615138ae20cc02013b595f36f02e21a63 (patch)
treea23cd06845aba746e8194fadc0f7cc4652cad51b /src/usr/htmgt/htmgt_utility.H
parentccb74685e3205a1f74e4a2264f27775144600d2c (diff)
downloadtalos-hostboot-7d4cab0615138ae20cc02013b595f36f02e21a63.tar.gz
talos-hostboot-7d4cab0615138ae20cc02013b595f36f02e21a63.zip
HTMGT: Memory Throttling and Power Capping support
- Enable DIMM thermal monitoring - Implement VRM thermal monitoring support - Implement memory throttle calculations - Move HTMGT only attributes to _openpower xml files System owner will need to update the following for full support: OPEN_POWER_MIN_MEM_UTILIZATION_POWER_CAP OPEN_POWER_VRM_READ_TIMEOUT_SEC Change-Id: Ib7f31e58c62af4b66edc3989156ebc6e636cc741 RTC: 153942 Reviewed-on: http://ralgit01.raleigh.ibm.com/gerrit1/41982 Tested-by: Jenkins Server <pfd-jenkins+hostboot@us.ibm.com> Reviewed-by: Martha Broyles <mbroyles@us.ibm.com> Tested-by: Jenkins OP Build CI <op-jenkins+hostboot@us.ibm.com> Tested-by: FSP CI Jenkins <fsp-CI-jenkins+hostboot@us.ibm.com> Reviewed-by: Daniel M. Crowell <dcrowell@us.ibm.com>
Diffstat (limited to 'src/usr/htmgt/htmgt_utility.H')
-rw-r--r--src/usr/htmgt/htmgt_utility.H2
1 files changed, 1 insertions, 1 deletions
diff --git a/src/usr/htmgt/htmgt_utility.H b/src/usr/htmgt/htmgt_utility.H
index 7872a1f78..5ef5d7457 100644
--- a/src/usr/htmgt/htmgt_utility.H
+++ b/src/usr/htmgt/htmgt_utility.H
@@ -117,7 +117,7 @@ namespace HTMGT
enum internalFlagTypes
{
FLAG_HALT_ON_OCC_SRC = 0x00800000, // Prevent resets after SRC
- FLAG_SEND_MEM_CONFIG = 0x00000800, // Enables sending mem config
+ FLAG_DISABLE_MEM_CONFIG = 0x00000800, // Disable sending mem config
FLAG_HALT_ON_RESET_FAIL = 0x00000100, // Stop additional resets
FLAG_EXT_RESET_DISABLED = 0x00000080, // Ignore opal-prd/BMC resets
FLAG_DISABLE_MEM_THROTTLE = 0x00000040,
OpenPOWER on IntegriCloud